@@ -1,5 +1,5 @@
 """
-Minimal Python library for working with bit vectors natively.
+Pure-Python library for working with bit vectors.
 """
 from __future__ import annotations
 from typing import Optional, Union, Sequence, Set
@@ -8,45 +8,133 @@ from parts import parts
 
 class bitlist:
     """
-    Data structure for representing bit vectors.
+    Data structure for representing bit vectors. The constructor accepts a
+    variety of input types (including integers, bytes-like objects, strings
+    of binary digits, lists of binary digits, and other :obj:`bitlist`
+    instances) and parses them in an appropriate manner to build a bit vector.
+    Integer arguments are converted into a big-endian binary representation.
+
+    >>> bitlist(1)
+    bitlist('1')
+    >>> bitlist(123)
+    bitlist('1111011')
+    >>> bitlist('1111011')
+    bitlist('1111011')
+    >>> bitlist(bytes([255, 254]))
+    bitlist('1111111111111110')
+    >>> bitlist([1, 0, 1, 1])
+    bitlist('1011')
+    >>> bitlist(bitlist('1010'))
+    bitlist('1010')
+
+    When the constructor is applied to a bytes-like object, the leading zero
+    digits (*i.e.*, those on the left-hand side) **are retained** (up to the
+    least multiple of eight larger than the minimum number of binary digits
+    required).
+
+    >>> bitlist(bytes([123]))
+    bitlist('01111011')
+    >>> bitlist(bytearray([123, 123]))
+    bitlist('0111101101111011')
+    >>> bitlist('01111011')
+    bitlist('01111011')
+
+    When the constructor is applied to an integer argument, the created bit
+    vector has leading (*i.e.*, left-hand) zeros truncated and contains the
+    minimum number of bits necessary to represent the supplied argument
+    (using a big-endian representation).
+
+    >>> bitlist(2)
+    bitlist('10')
+    >>> bitlist(16)
+    bitlist('10000')
+
+    The above implies that the empty bit vector represents (and is equivalent
+    to) the numerical value of zero.
+
+    >>> bitlist() == bitlist(0)
+    True
+    >>> bitlist() == bitlist('0')
+    True
+    >>> bitlist() == bitlist([])
+    True
+
+    For all other input types, the length of the vector (and consequently the
+    number of leading zeos) is preserved.
+
+    >>> bitlist('0000')
+    bitlist('0000')
+    >>> bitlist([0, 1, 1])
+    bitlist('011')
+    >>> bitlist([0, 0, 1, 1])
+    bitlist('0011')
+    >>> bitlist(bitlist('00010'))
+    bitlist('00010')
+
+    The ``length`` parameter can be used to specify the length of the bit
+    vector, overriding the default behaviors.
+
+    >>> bitlist(bytes([123]), 16)
+    bitlist('0000000001111011')
+    >>> bitlist(16, 64)
+    bitlist('0000000000000000000000000000000000000000000000000000000000010000')
+    >>> bitlist(bitlist(123), 8)
+    bitlist('01111011')
+
+    If the ``length`` parameter has a value that is less than the minimum
+    number of bits that would be included according to a default behavior, the
+    bit vector is truncated *on the left-hand side* to match the specified
+    length.
+
+    >>> bitlist(bytes([123]), 7)
+    bitlist('1111011')
+    >>> bitlist(bytes([123]), 4)
+    bitlist('1011')
+    >>> bitlist(bytes([123]), 2)
+    bitlist('11')
+    >>> bitlist(bytes([123]), 0)
+    bitlist('')
+    >>> bitlist(123, 0)
+    bitlist('')
+    >>> bitlist([1, 1, 1], 0)
+    bitlist('')
+
+    A :obj:`bitlist` instance can be converted into an integer using the
+    built-in :obj:`int` function. By default, a big-endian representation of
+    integers is used. The recommended approach for switching to a
+    little-endian representation is to reverse the bit vector.
+
+    >>> b = bitlist('1111011')
+    >>> int(b)
+    123
+    >>> int(bitlist(list(reversed(b))))
+    111
+
+    The :obj:`bitlist` constructor can be used to create a copy of an instance.
+
+    >>> xs = bitlist(123, 8)
+    >>> ys = bitlist(xs)
+    >>> ys[0] = 1
+    >>> xs
+    bitlist('01111011')
+    >>> ys
+    bitlist('11111011')
+
+    Any attempt to construct an instance using unsupported arguments raises an
+    exception.
+
+    >>> bitlist(float(1))
+    Traceback (most recent call last):
+      ...
+    ValueError: bitlist constructor received unsupported argument
     """
-    def __init__(self: bitlist, argument=None, length: Optional[int] = None):
+    def __init__(
+            self: bitlist,
+            argument: Union[int, str, bytes, bytearray, list, bitlist, None] = None,
+            length: Optional[int] = None
+        ):
         """
         Parse argument depending on its type and build a bit vector instance.
-
-        >>> bitlist() == bitlist('0')
-        True
-        >>> bitlist(123)
-        bitlist('1111011')
-        >>> int(bitlist('1111011'))
-        123
-        >>> bitlist(bytes([123]))
-        bitlist('01111011')
-        >>> bitlist(bytes([123]), 16)
-        bitlist('0000000001111011')
-        >>> bitlist(16, 64)
-        bitlist('0000000000000000000000000000000000000000000000000000000000010000')
-        >>> bitlist(bitlist('1010'))
-        bitlist('1010')
-        >>> bitlist(bitlist(123), 8)
-        bitlist('01111011')
-        >>> xs = bitlist(123, 8)
-        >>> ys = bitlist(xs)
-        >>> ys[0] = 1
-        >>> xs
-        bitlist('01111011')
-        >>> ys
-        bitlist('11111011')
-        >>> bitlist(bytes([123]), 4)
-        bitlist('1011')
-        >>> bitlist(bytes([123, 123]))
-        bitlist('0111101101111011')
-        >>> bitlist(bytes([1, 2, 3]))
-        bitlist('000000010000001000000011')
-        >>> bitlist(float(1))
-        Traceback (most recent call last):
-          ...
-        ValueError: bitlist constructor received unsupported argument
         """
         if argument is None:
             # By default, always return the bit vector representing zero.
@@ -84,11 +172,11 @@ class bitlist:
 
         elif isinstance(argument, bitlist):
             # Make constructor idempotent (but have it iterate
-            # to reflect the behavior of `list(...)`.
+            # to reflect the behavior of ``list``.
             self.bits = bytearray(list(argument.bits))
 
         else:
-            raise ValueError("bitlist constructor received unsupported argument")
+            raise ValueError('bitlist constructor received unsupported argument')
 
         if length is not None:
             # Pad or truncate the bit vector to ensure the specified length.
@@ -210,8 +298,8 @@ class bitlist:
         """
         if isinstance(other, int):
             return bitlist(list(reversed(list(self.bits)))*other)
-        else:
-            raise ValueError("repetition parameter must be an integer")
+
+        raise ValueError('repetition parameter must be an integer')
 
     def __truediv__(
         self: bitlist, other: Union[int, Set[int], Sequence[int]]
@@ -220,7 +308,8 @@ class bitlist:
         The division operator can be used to partition a bit vector into the
         specified number of parts, into parts of a specified length, or into
         a sequence of parts in which each part's length is specified in a
-        sequence of integers.
+        sequence of integers (leveraging and mirroring the capabilities of the
+        :obj:`~parts.parts.parts` function).
 
         >>> bitlist('11010001') / 2
         [bitlist('1101'), bitlist('0001')]
@@ -262,16 +351,18 @@ class bitlist:
         TypeError: bitlist indices must be integers or slices
         """
         if isinstance(key, int):
-            if key < 0: # Support "big-endian" interface using negative indices.
+            if key < 0: # Support big-endian interface using negative indices.
                 return self.bits[abs(key)-1] if abs(key) <= len(self.bits) else 0
-            elif key < len(self.bits):
+
+            if key < len(self.bits):
                 return self.bits[len(self.bits) - 1 - key]
-            else:
-                raise IndexError("bitlist index out of range")
-        elif isinstance(key, slice):
+
+            raise IndexError('bitlist index out of range')
+
+        if isinstance(key, slice):
             return bitlist(list(reversed(self.bits))[key])
-        else:
-            raise TypeError("bitlist indices must be integers or slices")
+
+        raise TypeError('bitlist indices must be integers or slices')
 
     def __setitem__(self: bitlist, i: int, b: int):
         """
@@ -286,7 +377,7 @@ class bitlist:
           ...
         IndexError: bitlist index out of range
         """
-        if i < 0: # Support "big-endian" interface using negative indices.
+        if i < 0: # Support big-endian interface using negative indices.
             self.bits =\
                 bytearray([
                     (self[j] if j != i else b)
@@ -300,7 +391,7 @@ class bitlist:
                     for j in range(0, len(self.bits))
                 ])
         else:
-            raise IndexError("bitlist index out of range")
+            raise IndexError('bitlist index out of range')
 
     def __lshift__(self: bitlist, n: Union[int, Set[int]]) -> bitlist:
         """
@@ -326,8 +417,8 @@ class bitlist:
         if isinstance(n, set) and len(n) == 1 and isinstance(list(n)[0], int):
             n = list(n)[0] % len(self) # Allow rotations to wrap around.
             return bitlist(list(self.bits[n:]) + list(self.bits[:n]))
-        else:
-            return bitlist(list(reversed(list([0] * n) + list(self.bits))))
+
+        return bitlist(list(reversed(list([0] * n) + list(self.bits))))
 
     def __rshift__(self: bitlist, n: Union[int, Set[int]]) -> bitlist:
         """
@@ -353,8 +444,8 @@ class bitlist:
         if isinstance(n, set) and len(n) == 1 and isinstance(list(n)[0], int):
             n = list(n)[0] % len(self) # Allow rotations to wrap around.
             return bitlist(list(self.bits[-n:]) + list(self.bits[:-n]))
-        else:
-            return bitlist(list(reversed(self.bits[n:])))
+
+        return bitlist(list(reversed(self.bits[n:])))
 
     def __and__(self: bitlist, other: bitlist) -> bitlist:
         """
@@ -369,8 +460,9 @@ class bitlist:
         """
         if len(self) != len(other):
             raise ValueError(
-                "arguments to logical operations must have equal lengths"
+                'arguments to logical operations must have equal lengths'
             )
+
         return bitlist(list(reversed(
             [a & b for (a, b) in zip(self.bits, other.bits)]
         )))
@@ -388,7 +480,7 @@ class bitlist:
         """
         if len(self) != len(other):
             raise ValueError(
-                "arguments to logical operations must have equal lengths"
+                'arguments to logical operations must have equal lengths'
             )
         return bitlist(list(reversed(
             [a | b for (a, b) in zip(self.bits, other.bits)]
@@ -407,7 +499,7 @@ class bitlist:
         """
         if len(self) != len(other):
             raise ValueError(
-                "arguments to logical operations must have equal lengths"
+                'arguments to logical operations must have equal lengths'
             )
         return bitlist(list(reversed(
             [a ^ b for (a, b) in zip(self.bits, other.bits)]
@@ -425,7 +517,7 @@ class bitlist:
 
     def __bool__(self: bitlist) -> bool:
         """
-        Any non-zero instance is interpreted as `True`.
+        Any non-zero instance is interpreted as ``True``.
 
         >>> bool(bitlist('0100'))
         True
@@ -522,5 +614,5 @@ class bitlist:
         """
         return int(self) >= int(other)
 
-if __name__ == "__main__":
+if __name__ == '__main__':
     doctest.testmod() # pragma: no cover
